@@ -25,14 +25,12 @@ enum ActivityState {
 };
 }
 
-K_PLUGIN_CLASS_WITH_JSON(RunApplicationPlugin, "kactivitymanagerd-plugin-runapplication.json")
+K_PLUGIN_CLASS(RunApplicationPlugin)
 
-RunApplicationPlugin::RunApplicationPlugin(QObject *parent, const QVariantList &args)
+RunApplicationPlugin::RunApplicationPlugin(QObject *parent)
     : Plugin(parent)
     , m_activitiesService(nullptr)
 {
-    Q_UNUSED(args);
-
     setName(QStringLiteral("org.kde.ActivityManager.RunApplication"));
 }
 
@@ -49,7 +47,7 @@ bool RunApplicationPlugin::init(QHash<QString, QObject *> &modules)
     connect(m_activitiesService, SIGNAL(CurrentActivityChanged(QString)), this, SLOT(currentActivityChanged(QString)));
     connect(m_activitiesService, SIGNAL(ActivityStateChanged(QString, int)), this, SLOT(activityStateChanged(QString, int)));
 
-    const auto currentActivity = Plugin::retrieve<QString>(m_activitiesService, "CurrentActivity", "QString");
+    const auto currentActivity = Plugin::retrieve<QString>(m_activitiesService, "CurrentActivity");
 
     currentActivityChanged(currentActivity);
 
@@ -123,3 +121,5 @@ void RunApplicationPlugin::executeIn(const QString &path) const
 // }
 
 #include "RunApplicationPlugin.moc"
+
+#include "moc_RunApplicationPlugin.cpp"
